@@ -1017,7 +1017,7 @@ typedef enum {
  * onscreen viewport.
  * @ATSPI_ROLE_WINDOW: A top level window with no title or border.
  * @ATSPI_ROLE_EXTENDED: means that the role for this item is known, but not
- * included in the core enumeration.
+ * included in the core enumeration. Deprecated since 2.24.
  * @ATSPI_ROLE_HEADER: An object that serves as a document header.
  * @ATSPI_ROLE_FOOTER: An object that serves as a document footer.
  * @ATSPI_ROLE_PARAGRAPH: An object which is contains a single paragraph of
@@ -1120,9 +1120,9 @@ typedef enum {
  * particular application.
  * @ATSPI_ROLE_INFO_BAR: An object designed to present a message to the user
  * within an existing window.
- *@ATSPI_ROLE_LEVEL_BAR: A bar that serves as a level indicator to, for
+ * @ATSPI_ROLE_LEVEL_BAR: A bar that serves as a level indicator to, for
  * instance, show the strength of a password or the state of a battery. 
- * Since: 2.8
+ *   Since: 2.8
  *@ATSPI_ROLE_TITLE_BAR: A bar that serves as the title of a window or a
  * dialog. @Since: 2.12
  *@ATSPI_ROLE_BLOCK_QUOTE: An object which contains a text section
@@ -1181,6 +1181,19 @@ typedef enum {
  * subscript. @Since: 2.16.
  *@ATSPI_ROLE_SUPERSCRIPT: An object that contains text that is displayed as a
  * superscript. @Since: 2.16.
+ *@ATSPI_ROLE_DESCRIPTION_LIST: An object that represents a list of term-value
+ * groups. A term-value group represents an individual description and consist
+ * of one or more names (@ATSPI_ROLE_DESCRIPTION_TERM) followed by one or more
+ * values (@ATSPI_ROLE_DESCRIPTION_VALUE). For each list, there should not be
+ * more than one group with the same term name. @Since: 2.26.
+ *@ATSPI_ROLE_DESCRIPTION_TERM: An object that represents the term, or name,
+ * part of a term-description group in a description list. @Since: 2.26.
+ *@ATSPI_ROLE_DESCRIPTION_VALUE: An object that represents the description,
+ * definition, or value of a term-description group in a description list.
+ * The values within a group are alternatives, meaning that you can have
+ * several @ATSPI_ROLE_DESCRIPTION_VALUE objects for a given
+ * @ATSPI_ROLE_DESCRIPTION_TERM. @Since: 2.26.
+ *@ATSPI_ROLE_FOOTNOTE: An object that contains the text of a footnote. @Since: 2.26.
  * @ATSPI_ROLE_LAST_DEFINED: Not a valid role, used for finding end of
  * enumeration.
  *
@@ -1310,6 +1323,10 @@ typedef enum {
     ATSPI_ROLE_MATH_ROOT,
     ATSPI_ROLE_SUBSCRIPT,
     ATSPI_ROLE_SUPERSCRIPT,
+    ATSPI_ROLE_DESCRIPTION_LIST,
+    ATSPI_ROLE_DESCRIPTION_TERM,
+    ATSPI_ROLE_DESCRIPTION_VALUE,
+    ATSPI_ROLE_FOOTNOTE,
     ATSPI_ROLE_LAST_DEFINED,
 } AtspiRole;
 
@@ -1318,7 +1335,7 @@ typedef enum {
  *
  * One higher than the highest valid value of #AtspiRole.
  */
-#define ATSPI_ROLE_COUNT (121+1)
+#define ATSPI_ROLE_COUNT (125+1)
 
 typedef enum
 {
