@@ -1037,6 +1037,18 @@ atspi_role_get_type (void)
 			{ ATSPI_ROLE_SUPERSCRIPT,
 			  "ATSPI_ROLE_SUPERSCRIPT",
 			  "superscript" },
+			{ ATSPI_ROLE_DESCRIPTION_LIST,
+			  "ATSPI_ROLE_DESCRIPTION_LIST",
+			  "description-list" },
+			{ ATSPI_ROLE_DESCRIPTION_TERM,
+			  "ATSPI_ROLE_DESCRIPTION_TERM",
+			  "description-term" },
+			{ ATSPI_ROLE_DESCRIPTION_VALUE,
+			  "ATSPI_ROLE_DESCRIPTION_VALUE",
+			  "description-value" },
+			{ ATSPI_ROLE_FOOTNOTE,
+			  "ATSPI_ROLE_FOOTNOTE",
+			  "footnote" },
 			{ ATSPI_ROLE_LAST_DEFINED,
 			  "ATSPI_ROLE_LAST_DEFINED",
 			  "last-defined" },
